Package: rgexf
Type: Package
Encoding: UTF-8
Title: Build, Import and Export GEXF Graph Files
Version: 0.15.3
Date: 2015-03-24
Author: George Vega Yon <gvegayon@caltech.edu> [aut], Jorge Fábrega Lacoa <jorge.fabrega@uai.cl> [ctb], Joshua B. Kunst <jbkunst@gmail.com> [ctb]
Maintainer: George Vega Yon <gvegayon@caltech.edu>
Description: Create, read and write GEXF (Graph Exchange XML Format) graph files (used in Gephi and others). Using the XML package, it allows the user to easily build/read graph files including attributes, GEXF viz attributes (such as color, size, and position), network dynamics (for both edges and nodes) and edge weighting. Users can build/handle graphs element-by-element or massively through data-frames, visualize the graph on a web browser through "sigmajs" (a javascript library) and interact with the igraph package.
URL: http://bitbucket.org/gvegayon/rgexf, http://www.ggvega.com
Depends: XML, Rook, igraph
License: GPL (>= 3)
LazyLoad: yes
Packaged: 2015-03-24 15:40:34 UTC; george
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2015-03-24 18:27:03
Built: R 3.5.1; x86_64-w64-mingw32; 2019-07-18 00:56:09 UTC; windows
Archs: x64
