import(XML)
import(Rook)
import(utils)
import(igraph)

export(.addNodesEdges, .defAtt)

# Parsing functions
export(checkTimes, .parseEdgesVizAtt, .parseNodesVizAtt, .parseEdgesWeight, 
       .parseEdgesAtt, .parseEdgesId, .parseNodesAtt, .parseEdgesLabel,
       .parseDataTypes, .build.and.validate.gexf)

export(write.gexf)
export(read.gexf)
export(new.gexf.graph)
export(add.gexf.node, rm.gexf.node, add.gexf.edge, rm.gexf.edge)
export(add.node.spell, add.edge.spell)
export(edge.list)

# Analysis functions
export(check.dpl.edges, switch.edges)

# Methods
S3method(print, gexf)
S3method(summary, gexf)
S3method(plot, gexf)

export(igraph.to.gexf, gexf.to.igraph)

# Source code
useDynLib(rgexf)
